aboutsummaryrefslogtreecommitdiff
path: root/tests/gcfver.c
diff options
context:
space:
mode:
Diffstat (limited to 'tests/gcfver.c')
-rw-r--r--tests/gcfver.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/tests/gcfver.c b/tests/gcfver.c
index b5c9bab..65b01d3 100644
--- a/tests/gcfver.c
+++ b/tests/gcfver.c
@@ -1,4 +1,4 @@
/* grecs - Gray's Extensible Configuration System
Copyright (C) 2007-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it
@@ -18,12 +18,12 @@
# include <config.h>
#endif
#include <stdlib.h>
-#include "grecs.h"
+#include "argot.h"
int
main(int argc, char **argv)
{
- struct grecs_version_info *vinfo;
+ struct argot_version_info *vinfo;
int res;
if (argc > 3) {
@@ -31,12 +31,12 @@ main(int argc, char **argv)
exit(1);
}
if (argc == 2)
- exit(!grecs_version_ok(argv[1]));
+ exit(!argot_version_ok(argv[1]));
if (argc == 3)
- exit(grecs_version_cmp(argv[1], argv[2], &res) ? 1 :
+ exit(argot_version_cmp(argv[1], argv[2], &res) ? 1 :
res == 0 ? 0 : res < 0 ? 2 : 3);
/* Default action: */
- vinfo = grecs_version();
+ vinfo = argot_version();
printf("package: %s\n", vinfo->package);
printf("version: %s\n", vinfo->version);
printf("major: %d\n", vinfo->major);
@@ -46,7 +46,7 @@ main(int argc, char **argv)
if (vinfo->suffix && vinfo->suffix[0])
printf(" %s", vinfo->suffix);
putchar('\n');
- grecs_version_info_free(vinfo);
+ argot_version_info_free(vinfo);
exit(0);
}
@@ -1,4 +1,4 @@
-/* grecs - Gray's Extensible Configuration System
+/* argot - Gray's Extensible Configuration System
Copyright (C) 2007-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it

Return to:

Send suggestions and report system problems to the System administrator.